@@ -5,6 +5,7 @@ from .model import ModelBase
 from .models import (
     AnthropicLLM,
     AzureAILLM,
+    CohereLLM,
     GeminiLLM,
     HuggingFaceLLM,
     OllamaLLM,
@@ -25,10 +26,10 @@ __all__ = [
     "Tool",
     "Parameter",
     "AnthropicLLM",
+    "AzureAILLM",
+    "CohereLLM",
     "HuggingFaceLLM",
     "OpenAILLM",
     "GeminiLLM",
     "OllamaLLM",
-    "AzureAILLM",
-    "GeminiLLM",
 ]
